@@ -23,23 +23,30 @@
 buildTree <- function(disDat, startFr=NULL, posCo=c("beg","end"), silent=FALSE, callFrom=NULL){
   fxNa <- .composeCallName(callFrom, newNa="buildTree")
   if(!isTRUE(silent)) silent <- FALSE
+  datOK <- TRUE
+  if(length(disDat) <1) datOK <- FALSE
   if(length(dim(disDat)) <2) disDat <- matrix(disDat, nrow=1, dimnames=list("1",names(disDat))) # assume as single entry
   rowNa <- rownames(disDat)
   if(is.null(rowNa)) rowNa <- 1:nrow(disDat)
-  chCol <- match(colnames(disDat),posCo)
+  chCol <- match(colnames(disDat), posCo)
   disDat <- if(sum(is.na(chCol[1:2])) <1) {
     cbind(beg=as.integer(disDat[,chCol[1]]), end=as.numeric(disDat[,chCol[2]]))
   } else disDat <- as.matrix(disDat[,1:2])
   rownames(disDat) <- rowNa
   chSlash <- grep("/", rownames(disDat))
-  if(length(chSlash) >0) message(fxNa,": TROUBLE ahead, names of nodes should NOT contain '/' !!")
+  if(length(chSlash) >0) message(fxNa,"TROUBLE ahead, names of nodes should NOT contain '/' !!")
   disDat <- cbind(disDat[,1:2], le=disDat[,2] -disDat[,1] +1)            # add col for length # if(ncol(disDat)==2)   
-  if(requireNamespace("data.tree", quietly=TRUE)) {
-    warning(fxNa,": package 'data.tree' missing ! Please install from CRAN first .. returning NULL)")
+  if(!requireNamespace("data.tree", quietly=TRUE)) {
+    warning(fxNa,"Package 'data.tree' missing ! Please install from CRAN first .. returning NULL)")
+    datOK <- FALSE
   } else {
+  	## check if package is functioning  
+    setX <- try(data.tree::Node$new("_Root_"))        # virtual node as generic root,  need to avoid reserved names (see NODE_RESERVED_NAMES_CONST)
+    if(inherits(setX, "try-error")) { datOK <- FALSE
+      warning(fxNa,"Problem running package data-tree : Can't even create a new generic node")}
+  }   
+  if(datOK) {  
   	## main  
-    setX <- try(data.tree::Node$new("_Root_",len=0))        # virtual node as generic root,  need to avoid reserved names (see NODE_RESERVED_NAMES_CONST)
-    if(inherits(setX, "try-error")) stop(fxNa,": Problem running package data-tree : Can't even create a new generic node")
     ## check for dupl
     chDup <- duplicated(paste(disDat[,1],disDat[,2],sep="_"), fromLast=FALSE)
     names(chDup) <- rownames(disDat)
@@ -48,12 +55,12 @@ buildTree <- function(disDat, startFr=NULL, posCo=c("beg","end"), silent=FALSE,
       hasDu <- chDu2 & !chDup                    # the originals (of dupl) to keep
       names(hasDu) <- rownames(disDat)
       ## remove duplicated/redundant
-      dupDat <- lapply(which(hasDu),function(x) {z <- paste(disDat[,2],disDat[,1],sep="_"); which(z %in% z[x])})  # index of replicated elements (line-no)
-      if(!silent) message(fxNa,": ",sapply(dupDat,function(x) {y <- names(chDup)[x]; paste("  ",y[1]," duplicated by ",paste(y[-1],collapse=" "),"\n  ")}))
+      dupDat <- lapply(which(hasDu), function(x) {z <- paste(disDat[,2],disDat[,1],sep="_"); which(z %in% z[x])})  # index of replicated elements (line-no)
+      if(!silent) message(fxNa,": ", sapply(dupDat, function(x) {y <- names(chDup)[x]; paste("  ",y[1]," duplicated by ",paste(y[-1],collapse=" "),"\n  ")}))
       disDat <- disDat[which(!chDup),]           # cleaned main data
     } else dupDat <- NULL
     ## check possible start sites
-    nodeWPrev <- sort(unique(names(which(rep(disDat[,1],nrow(disDat)) == rep(disDat[,2]+1, each=nrow(disDat))))))
+    nodeWPrev <- sort(unique(names(which(rep(disDat[,1], nrow(disDat)) == rep(disDat[,2] +1, each=nrow(disDat))))))
     rootBaseNa <- if(length(nodeWPrev) >0) rownames(disDat)[which(!rownames(disDat) %in% nodeWPrev)] else rownames(disDat)
     rootBase <- which(rownames(disDat) %in% rootBaseNa)
     names(rootBase) <- rootBaseNa
@@ -63,8 +70,8 @@ buildTree <- function(disDat, startFr=NULL, posCo=c("beg","end"), silent=FALSE,
     if(!startFr %in% rootBase) { if(!silent) message(fxNa,": choice of 'startFr' is not close to root, resetting to ",rootBase[1]," ('",names(rootBase)[1],"')")
       startFr <- rootBase[1] } 
     names(startFr) <- rownames(disDat)[startFr]
-    tm1 <- disDat[,1] == disDat[startFr,2]+1              # startFr has following
-    tm1 <- list(lo=tm1, it=0+tm1, preN=rep(NA,nrow(disDat)), disDat=disDat,iter=1,start=startFr)     
+    tm1 <- disDat[,1] == disDat[startFr,2] +1              # startFr has following
+    tm1 <- list(lo=tm1, it=0 +tm1, preN=rep(NA,nrow(disDat)), disDat=disDat, iter=1, start=startFr)     
     ## grow 1st branch
     if(any(tm1$lo)) tm1 <- .growTree(tm1,setX) else {
       x1 <- setX$AddChild(names(startFr), len=disDat[startFr,3])
@@ -77,7 +84,7 @@ buildTree <- function(disDat, startFr=NULL, posCo=c("beg","end"), silent=FALSE,
       while(any(chSup)) {
         j <- which(chSup)[1]
         tm3 <- disDat[,1]== disDat[j,2] +1
-        tm3 <- list(lo=tm3, it=0+tm3, preN=rep(NA,nrow(disDat)), disDat=disDat, iter=1, start=j)
+        tm3 <- list(lo=tm3, it=0 +tm3, preN=rep(NA,nrow(disDat)), disDat=disDat, iter=1, start=j)
         tm3 <- .growTree(tm3,setX)
         chSup[j] <- FALSE }
     } else tm3 <- NULL     
@@ -95,14 +102,14 @@ buildTree <- function(disDat, startFr=NULL, posCo=c("beg","end"), silent=FALSE,
       ## need list indicating which node(s) is/are duplicate of which node : dupDat
       replOut <- function(x,chDup,out) {   # fetch original of eliminated duplicated elements, reconstruct output with adjusted rownames
         se <- function(v) paste0("/",v,"/")
-        y <- grep(se(names(chDup)[x[1]]),se(rownames(out))) 
+        y <- grep(se(names(chDup)[x[1]]), se(rownames(out))) 
         z <- se(rownames(out)[y])
         w <- sub("^/","",sub("/$","",sapply(names(chDup)[x[-1]], function(w) sub(se(names(chDup)[x[1]]), se(w),z))))
-        matrix(rep(t(out[y,]),length(x)-1), ncol=ncol(out), dimnames=list(w,colnames(out)), byrow=TRUE) }
-       replOut(dupDat[[1]],chDup,out)
-      supMat <- lapply(dupDat, replOut,chDup,out)
-      out2 <- matrix(unlist(sapply(supMat,as.integer)), ncol=ncol(out), byrow=FALSE)
-      dimnames(out2) <- list(unlist(sapply(supMat,rownames)), colnames(out))
+        matrix(rep(t(out[y,]), length(x)-1), ncol=ncol(out), dimnames=list(w,colnames(out)), byrow=TRUE) }
+       replOut(dupDat[[1]], chDup, out)
+      supMat <- lapply(dupDat, replOut, chDup, out)
+      out2 <- matrix(unlist(sapply(supMat, as.integer)), ncol=ncol(out), byrow=FALSE)
+      dimnames(out2) <- list(unlist(sapply(supMat, rownames)), colnames(out))
       out <- rbind(out, out2)  
     }
     list(paths=out, usedNodes=sort(names(chSup)[which(!chSup)]), tree=setX ) 
@@ -116,16 +123,16 @@ buildTree <- function(disDat, startFr=NULL, posCo=c("beg","end"), silent=FALSE,
     ## 'addToObj' .. data.tree object (branch on which to add new branches/nodes)
     #addToObj <- if(tm$iter==1 & length(addToObj) >0) addToObj else paste0("b",tm$it[j],"_",j)
     newNodeNa <- paste0("b",0,"_",tm$disDat[tm$start,1])
-    namesX <- deparse(substitute(setX))    #deparse(substitute(tm)))            # name of tree-object (typically 'setX'  )
-    assign(newNodeNa, get(namesX)$AddChild(rownames(tm$disDat)[tm$start],len=tm$disDat[tm$start,3]))      # add new 1st level branch to '_Root_'
+    namesX <- deparse(substitute(setX))      #deparse(substitute(tm)))            # name of tree-object (typically 'setX'  )
+    assign(newNodeNa, get(namesX)$AddChild(rownames(tm$disDat)[tm$start], len=tm$disDat[tm$start,3]))      # add new 1st level branch to '_Root_'
     if(any(tm$lo)) tm$preN[which(tm$lo)] <- newNodeNa
     while(any(tm$lo)) {        # need to grow further ..
-      tm$iter <- tm$iter+1
+      tm$iter <- tm$iter +1
       j <- which(tm$lo)[1]
       addToObj <- if(tm$iter==2) newNodeNa else tm$preN[j]    
       assign(paste0("b",tm$it[j],"_",j), get(addToObj)$AddChild(rownames(tm$disDat)[j],len=tm$disDat[j,3])) 
       tm$lo[j] <- FALSE                                          # this one is done ...
-      tm0 <- tm$disDat[,1]== tm$disDat[j,2]+1                    # test for potential children
+      tm0 <- tm$disDat[,1]== tm$disDat[j,2] +1                    # test for potential children
       if(any(tm0)) {z <- which(tm0);                        
         tm$lo[z] <- TRUE                                        # set to-do status for children
         tm$it[z] <- tm$it[j]+1                                  # tree-level 
